# cat-fact

`catFact` Get random cat facts from the internet

## Installation Instructions

```bash
$ pip install cat-fact
```

### Want bleeding edge version?

Create and activate virtual environment.

```bash
$ virtualenv venv
$ source ./venv/bin/activate
```
Now run `python setup.py install`, this will install `catFact` command into the virtual environment

If running `catFact` says command not found, deactivate and activate the virtual environment. That should fix it.

## Example

```bash
$ catFact
Julius Ceasar, Henri II, Charles XI, and Napoleon were all afraid of cats.
```
